@@ -25,6 +25,7 @@ impl Check for Checker<EnglishChecker> {
     }
 
     fn check(&self, input: &str) -> CheckResult {
+        let original_input = input;
         // Normalise the string
         let input = normalise_string(input);
         trace!("Checking English for sentence {}", input);
@@ -36,7 +37,7 @@ impl Check for Checker<EnglishChecker> {
 
         let mut plaintext_found = false;
         // TODO: Change this when the below bugs are fixed.
-        let filename = "English.txt";
+        let filename = "English text";
 
         let split_input = input.split(' ');
 
@@ -65,8 +66,11 @@ impl Check for Checker<EnglishChecker> {
             );
             // TODO: We are also typecasting to f64 instead of usize, which costs CPU cycles.
             if words_found / (input.split(' ').count()) as f64 > PLAINTEXT_DETECTION_PERCENTAGE {
-                debug!("Found {} words in {}", words_found, input);
-                debug!("Returning from English chekcer successfully with {}", input);
+                debug!("Found {} words in {}", words_found, original_input);
+                debug!(
+                    "Returning from English chekcer successfully with {}",
+                    original_input
+                );
                 plaintext_found = true;
                 break;
             }
@@ -74,7 +78,7 @@ impl Check for Checker<EnglishChecker> {
 
         CheckResult {
             is_identified: plaintext_found,
-            text: input.to_string(),
+            text: original_input.to_string(),
             checker_name: self.name,
             checker_description: self.description,
             description: filename.to_string(),
@@ -92,7 +96,9 @@ fn normalise_string(input: &str) -> String {
     // The replace function supports patterns https://doc.rust-lang.org/std/str/pattern/trait.Pattern.html#impl-Pattern%3C%27a%3E-3
     // TODO add more puncuation
     input.to_lowercase().replace(
-        &['(', ')', '!', '/', ',', '?', '\"', '.', ';', ':', '\''][..],
+        &[
+            '(', ')', '!', '/', ',', '?', '\"', '.', ';', ':', '\'', '`', ';', ':', '~', '^',
+        ][..],
         "",
     )
 }
