@@ -3,14 +3,14 @@ use crossbeam::{channel::bounded, select};
 use log::{error, trace};
 use std::collections::HashSet;
 
-use crate::{filtration_system::MyResults, timer, Text};
+use crate::{filtration_system::MyResults, timer, DecoderResult};
 
 /// Breadth first search is our search algorithm
 /// https://en.wikipedia.org/wiki/Breadth-first_search
-pub fn bfs(input: &str) -> Option<Text> {
+pub fn bfs(input: &str) -> Option<DecoderResult> {
     let config = get_config();
-    let initial = Text {
-        text: input.to_string(),
+    let initial = DecoderResult {
+        text: vec![input.to_string()],
         path: vec![],
     };
     let mut seen_strings = HashSet::new();
@@ -27,19 +27,20 @@ pub fn bfs(input: &str) -> Option<Text> {
         trace!("Number of potential decodings: {}", current_strings.len());
         trace!("Current depth is {:?}", curr_depth);
 
-        let mut new_strings: Vec<Text> = vec![];
+        let mut new_strings: Vec<DecoderResult> = vec![];
 
         current_strings.into_iter().try_for_each(|current_string| {
-            let res = super::perform_decoding(&current_string.text);
+            let res = super::perform_decoding(&current_string.text[0]);
 
             match res {
                 // if it's Break variant, we have cracked the text successfully
                 // so just stop processing further.
                 MyResults::Break(res) => {
                     let mut decoders_used = current_string.path;
-                    decoders_used.push(res.decoder);
-                    let result_text = Text {
-                        text: res.unencrypted_text.unwrap_or_default(),
+                    let text = res.unencrypted_text.clone().unwrap_or_default();
+                    decoders_used.push(res);
+                    let result_text = DecoderResult {
+                        text,
                         path: decoders_used,
                     };
 
@@ -54,9 +55,16 @@ pub fn bfs(input: &str) -> Option<Text> {
                             .into_iter()
                             .map(|r| {
                                 let mut decoders_used = current_string.path.clone();
-                                decoders_used.push(r.decoder);
-                                Text {
-                                    text: r.unencrypted_text.unwrap_or_default(),
+                                // text is a vector of strings
+                                let text = r.unencrypted_text.clone().unwrap_or_default();
+                                decoders_used.push(r);
+                                DecoderResult {
+                                    // and this is a vector of strings
+                                    // TODO we should probably loop through all `text` and create Text structs for each one
+                                    // and append those structs
+                                    // I think we should keep text as a single string
+                                    // and just create more of them....
+                                    text,
                                     path: decoders_used,
                                 }
                             })
@@ -66,7 +74,17 @@ pub fn bfs(input: &str) -> Option<Text> {
                 }
             }
         });
-        current_strings = new_strings;
+        let mut new_strings_to_be_added = Vec::new();
+        for text_struct in new_strings {
+            for decoded_text in text_struct.text {
+                new_strings_to_be_added.push(DecoderResult {
+                    text: vec![decoded_text],
+                    // quick hack
+                    path: text_struct.path.clone(),
+                })
+            }
+        }
+        current_strings = new_strings_to_be_added;
         curr_depth += 1;
 
         select! {
@@ -76,11 +94,13 @@ pub fn bfs(input: &str) -> Option<Text> {
                 // but this is a demo and i'll be lazy :P
                 let exit_result = exit_result.ok(); // convert Result to Some
                 if exit_result.is_some() {
+                    println!("Ares has decoded {times} times", times=curr_depth * (12+25));
                     trace!("Found exit result: {:?}", exit_result);
                     return exit_result;
                 }
             },
             recv(timer) -> _ => {
+                println!("Ares has decoded {times} times", times=curr_depth * (12+25));
                 error!("Ares failed to decrypt the text you have provided within {} seconds, it is unlikely to be decoded.", config.timeout);
                 return None;
             },
@@ -100,12 +120,10 @@ mod tests {
     #[test]
     fn bfs_succeeds() {
         // this will work after english checker can identify "CANARY: hello"
-        // let result = bfs("Q0FOQVJZOiBoZWxsbw==");
-        // assert!(result.is_some());
-        // assert!(result.unwrap() == "CANARY: hello");
         let result = bfs("b2xsZWg=");
         assert!(result.is_some());
-        assert!(result.unwrap().text == "hello");
+        let txt = result.unwrap().text;
+        assert!(txt[0] == "hello");
     }
 
     // Vector storing the strings to perform decoding in next iteraion
@@ -115,13 +133,13 @@ mod tests {
     // We want strings from all results, so to fix it,
     // we call .extend() to extend the vector.
     // Link to forum https://discord.com/channels/754001738184392704/1002135076034859068
+    // This also tests the bug whereby each iteration of caesar was not passed to the next decoder
+    // So in Ciphey only Rot1(X) was passed to base64, not Rot13(X)
     #[test]
     fn non_deterministic_like_behaviour_regression_test() {
-        // text was too long, so we put \ to escape the \n
-        // and put the rest of string on next line.
-        let result = bfs("UFRCRVRWVkNiRlZMTVVkYVVFWjZVbFZPU0\
-        dGMU1WVlpZV2d4VkRVNWJWWnJjRzFVUlhCc1pYSlNWbHBPY0VaV1ZXeHJWRWd4TUZWdlZsWlg=");
+        // Caesar Cipher (Rot13) -> Base64
+        let result = bfs("MTkyLjE2OC4wLjE=");
         assert!(result.is_some());
-        assert_eq!(result.unwrap().text, "https://www.google.com");
+        assert_eq!(result.unwrap().text[0], "192.168.0.1");
     }
 }
